@@ -29,7 +29,7 @@
 
 #include "xeus-python/xdebugger.hpp"
 #include "xdebugpy_client.hpp"
-#include "xutils.hpp"
+#include "xinternal_utils.hpp"
 
 namespace nl = nlohmann;
 namespace py = pybind11;
@@ -130,15 +130,21 @@ namespace xpyt
 
     bool debugger::start_debugpy()
     {
-        // import debugpy 
+        // import debugpy
         std::string code = "import debugpy;";
         // specify sys.executable
+        if (std::getenv("XEUS_LOG") != nullptr)
+        {
+            std::ofstream out("xeus.log", std::ios_base::app);
+            out << "===== DEBUGGER CONFIG =====" << std::endl;
+            out << m_debugger_config.dump() << std::endl;
+        }
         auto it = m_debugger_config.find("python");
         if (it != m_debugger_config.end())
         {
             code += "debugpy.configure({\'python\': \'" + it->template get<std::string>()  + "\'});";
         }
-        // call to debugpy.listen 
+        // call to debugpy.listen
         code += "debugpy.listen((\'" + m_debugpy_host + "\'," + m_debugpy_port + "))";
         nl::json json_code;
         json_code["code"] = code;
@@ -208,7 +214,7 @@ namespace xpyt
 
     xeus::xdebugger_info debugger::get_debugger_info() const
     {
-        return xeus::xdebugger_info(get_hash_seed(),
+        return xeus::xdebugger_info(xeus::get_tmp_hash_seed(),
                                     get_tmp_prefix(),
                                     get_tmp_suffix());
     }
@@ -217,7 +223,7 @@ namespace xpyt
     {
         return get_cell_tmp_file(code);
     }
-    
+
     std::unique_ptr<xeus::xdebugger> make_python_debugger(zmq::context_t& context,
                                                           const xeus::xconfiguration& config,
                                                           const std::string& user_name,
@@ -227,4 +233,3 @@ namespace xpyt
         return std::unique_ptr<xeus::xdebugger>(new debugger(context, config, user_name, session_id, debugger_config));
     }
 }
-
