@@ -25,17 +25,18 @@
 
 #include "xeus-python/xinterpreter.hpp"
 #include "xeus-python/xeus_python_config.hpp"
+#include "xeus-python/xtraceback.hpp"
+#include "xeus-python/xutils.hpp"
 
 #include "xpython_kernel.hpp"
 #include "xdisplay.hpp"
 #include "xinput.hpp"
 #include "xinspect.hpp"
+#include "xinteractiveshell.hpp"
+#include "xinternal_utils.hpp"
 #include "xis_complete.hpp"
 #include "xlinecache.hpp"
 #include "xstream.hpp"
-#include "xtraceback.hpp"
-#include "xutils.hpp"
-#include "xinteractiveshell.hpp"
 
 namespace py = pybind11;
 namespace nl = nlohmann;
@@ -166,7 +167,7 @@ namespace xpyt
         {
             // Import modules
             py::module ast = py::module::import("ast");
-            py::module builtins = py::module::import(XPYT_BUILTINS);
+            py::module builtins = py::module::import("builtins");
 
             // Parse code to AST
             py::object code_ast = ast.attr("parse")(code_copy, "<string>", "exec");
@@ -379,7 +380,7 @@ namespace xpyt
         {
             // Import modules
             py::module ast = py::module::import("ast");
-            py::module builtins = py::module::import(XPYT_BUILTINS);
+            py::module builtins = py::module::import("builtins");
 
             // Parse code to AST
             py::object code_ast = ast.attr("parse")(code, "<string>", "exec");
@@ -424,7 +425,10 @@ namespace xpyt
             py::module sys = py::module::import("sys");
             sys.attr("displayhook") = m_displayhook;
         }
+
+        // Expose display functions to Python
         py::globals()["display"] = display_module.attr("display");
+        py::globals()["update_display"] = display_module.attr("update_display");
     }
 
     void interpreter::load_extensions()
